@@ -33,6 +33,7 @@ var group__arrayfire__func =
     [ "cbrt", "group__arith__func__cbrt.htm", "group__arith__func__cbrt" ],
     [ "ceil", "group__arith__func__ceil.htm", "group__arith__func__ceil" ],
     [ "cholesky", "group__lapack__factor__func__cholesky.htm", "group__lapack__factor__func__cholesky" ],
+    [ "clamp", "group__arith__func__clamp.htm", "group__arith__func__clamp" ],
     [ "col/cols", "group__array__mem__col.htm", "group__array__mem__col" ],
     [ "colorSpace", "group__image__func__colorspace.htm", "group__image__func__colorspace" ],
     [ "complex", "group__arith__func__cplx.htm", "group__arith__func__cplx" ],
@@ -123,8 +124,8 @@ var group__arrayfire__func =
     [ "isHalfAvailable", "group__device__func__half.htm", "group__device__func__half" ],
     [ "isImageIoAvailable", "group__imageio__func__available.htm", "group__imageio__func__available" ],
     [ "isLAPACKAvailable", "group__lapack__helper__func__available.htm", "group__lapack__helper__func__available" ],
-    [ "isNan", "group__arith__func__isnan.htm", "group__arith__func__isnan" ],
     [ "isinf", "group__arith__func__isinf.htm", "group__arith__func__isinf" ],
+    [ "isnan", "group__arith__func__isnan.htm", "group__arith__func__isnan" ],
     [ "iszero", "group__arith__func__iszero.htm", "group__arith__func__iszero" ],
     [ "iterativeDeconv", "group__image__func__iterative__deconv.htm", "group__image__func__iterative__deconv" ],
     [ "join", "group__manip__func__join.htm", "group__manip__func__join" ],
@@ -135,6 +136,7 @@ var group__arrayfire__func =
     [ "log", "group__arith__func__log.htm", "group__arith__func__log" ],
     [ "log10", "group__arith__func__log10.htm", "group__arith__func__log10" ],
     [ "log1p", "group__arith__func__log1p.htm", "group__arith__func__log1p" ],
+    [ "log2", "group__arith__func__log2.htm", null ],
     [ "lookup", "group__index__func__lookup.htm", "group__index__func__lookup" ],
     [ "lower", "group__data__func__lower.htm", "group__data__func__lower" ],
     [ "lt", "group__arith__func__lt.htm", "group__arith__func__lt" ],
@@ -149,8 +151,8 @@ var group__arrayfire__func =
     [ "meanshift", "group__image__func__mean__shift.htm", "group__image__func__mean__shift" ],
     [ "medfilt", "group__image__func__medfilt.htm", "group__image__func__medfilt" ],
     [ "median", "group__stat__func__median.htm", "group__stat__func__median" ],
-    [ "min", "group__reduce__func__min.htm", "group__reduce__func__min" ],
     [ "min", "group__arith__func__min.htm", "group__arith__func__min" ],
+    [ "min", "group__reduce__func__min.htm", "group__reduce__func__min" ],
     [ "minByKey", "group__reduce__func__min__by__key.htm", "group__reduce__func__min__by__key" ],
     [ "minfilt", "group__image__func__minfilt.htm", "group__image__func__minfilt" ],
     [ "mod", "group__arith__func__mod.htm", "group__arith__func__mod" ],
@@ -174,6 +176,7 @@ var group__arrayfire__func =
     [ "pinned", "group__device__func__pinned.htm", "group__device__func__pinned" ],
     [ "pinverse", "group__lapack__ops__func__pinv.htm", "group__lapack__ops__func__pinv" ],
     [ "pow", "group__arith__func__pow.htm", "group__arith__func__pow" ],
+    [ "pow2", "group__arith__func__pow2.htm", "group__arith__func__pow2" ],
     [ "print", "group__print__func__print.htm", "group__print__func__print" ],
     [ "product", "group__reduce__func__product.htm", "group__reduce__func__product" ],
     [ "productByKey", "group__reduce__func__product__by__key.htm", "group__reduce__func__product__by__key" ],
@@ -215,6 +218,7 @@ var group__arrayfire__func =
     [ "setunique", "group__set__func__unique.htm", "group__set__func__unique" ],
     [ "shift", "group__manip__func__shift.htm", "group__manip__func__shift" ],
     [ "sift", "group__cv__func__sift.htm", "group__cv__func__sift" ],
+    [ "sigmoid", "group__arith__func__sigmoid.htm", "group__arith__func__sigmoid" ],
     [ "sign", "group__arith__func__sign.htm", "group__arith__func__sign" ],
     [ "sin", "group__arith__func__sin.htm", "group__arith__func__sin" ],
     [ "sinh", "group__arith__func__sinh.htm", "group__arith__func__sinh" ],
@@ -242,7 +246,7 @@ var group__arrayfire__func =
     [ "susan", "group__cv__func__susan.htm", "group__cv__func__susan" ],
     [ "svd", "group__lapack__factor__func__svd.htm", "group__lapack__factor__func__svd" ],
     [ "sync", "group__device__func__sync.htm", "group__device__func__sync" ],
-    [ "tan/tan2", "group__arith__func__tan.htm", "group__arith__func__tan" ],
+    [ "tan", "group__arith__func__tan.htm", "group__arith__func__tan" ],
     [ "tanh", "group__arith__func__tanh.htm", "group__arith__func__tanh" ],
     [ "tgamma", "group__arith__func__tgamma.htm", "group__arith__func__tgamma" ],
     [ "tile", "group__manip__func__tile.htm", "group__manip__func__tile" ],
