@@ -10,7 +10,9 @@ var group__explog__mat =
     [ "log", "group__arith__func__log.htm", "group__arith__func__log" ],
     [ "log10", "group__arith__func__log10.htm", "group__arith__func__log10" ],
     [ "log1p", "group__arith__func__log1p.htm", "group__arith__func__log1p" ],
+    [ "log2", "group__arith__func__log2.htm", null ],
     [ "pow", "group__arith__func__pow.htm", "group__arith__func__pow" ],
+    [ "pow2", "group__arith__func__pow2.htm", "group__arith__func__pow2" ],
     [ "root", "group__arith__func__root.htm", "group__arith__func__root" ],
     [ "rsqrt", "group__arith__func__rsqrt.htm", "group__arith__func__rsqrt" ],
     [ "sqrt", "group__arith__func__sqrt.htm", "group__arith__func__sqrt" ],
